@@ -1,6 +1,8 @@
 import copy
 
+import click
 from deepdiff import DeepDiff
+from deepdiff.model import REPORT_KEYS
 from nested_lookup import nested_delete
 
 #from response_differ import play, get_grouped_exception
@@ -25,12 +27,14 @@ def check_diff_responses():
                 old = _filter(old, filters=paths[i['uri']])
                 new = _filter(new, filters=paths[i['uri']])
             result = DeepDiff(old, new, ignore_order=True)
-            print(result)
-            if result.get('values_changed'):
+
+            if any(key in list(REPORT_KEYS) for key in result.keys()):
+                click.secho(f"  {'ID'}                      | {i['id']}")
+                click.secho(f"  {'Difference'}              | {result}")
                 message = f"ERROR {result}"
                 play.Replayed.errors.append(AssertionError(message))
-                exception_cls = get_grouped_exception(*play.Replayed.errors)
-                raise exception_cls(play.Replayed.errors)
+                #exception_cls = get_grouped_exception(*play.Replayed.errors)
+                #raise exception_cls(play.Replayed.errors)
 
 
 def _filter(resp, filters):
